pub struct LineEndingsSection {
pub omap: String,
pub imap: String,
pub emap: String,
}Expand description
Line-ending mappers.
Fields
omap: StringOutput map applied to bytes sent to the device.
imap: StringInput map applied to bytes received from the device.
emap: StringEcho map applied to locally-echoed bytes.